@@ -7,7 +7,7 @@
 #' For non-Gaussian models, the smoothing is based on the approximate Gaussian 
 #' model.
 #'
-#' @param model Model model.
+#' @inheritParams gaussian_approx
 #' @param ... Ignored.
 #' @return Matrix containing the smoothed estimates of states, or a list
 #' with the smoothed states and the variances.
@@ -17,7 +17,14 @@ fast_smoother <- function(model, ...) {
   UseMethod("fast_smoother", model)
 }
 #' @method fast_smoother gaussian
+#' @rdname smoother
 #' @export
+#' @examples
+#' model <- bsm_lg(Nile, 
+#'   sd_level = tnormal(120, 100, 20, min = 0),
+#'   sd_y = tnormal(50, 50, 25, min = 0),
+#'   a1 = 1000, P1 = 200)
+#' ts.plot(cbind(Nile, fast_smoother(model)), col = 1:2)
 fast_smoother.gaussian <- function(model, ...) {
   
   out <- gaussian_fast_smoother(model, model_type(model))
@@ -37,7 +44,17 @@ smoother <- function(model, ...) {
   UseMethod("smoother", model)
 }
 #' @method smoother gaussian
+#' @rdname smoother
 #' @export
+#' @examples
+#' model <- bsm_lg(Nile, 
+#'   sd_y = tnormal(120, 100, 20, min = 0),
+#'   sd_level = tnormal(50, 50, 25, min = 0),
+#'   a1 = 1000, P1 = 500^2)
+#' 
+#' out <- smoother(model)
+#' ts.plot(cbind(Nile, out$alphahat), col = 1:2)
+#' ts.plot(sqrt(out$Vt[1, 1, ]))
 smoother.gaussian <- function(model, ...) {
   
   out <-  gaussian_smoother(model, model_type(model))
@@ -65,16 +82,44 @@ smoother.nongaussian <- function(model, ...) {
 #' variances. Function \code{ekf_fast_smoother} computes only smoothed 
 #' estimates of the states.
 #'
-#' @param model Model model
-#' @param iekf_iter If \code{iekf_iter > 0}, iterated extended Kalman filter is 
-#' used with \code{iekf_iter} iterations.
+#' @inheritParams ekf
 #' @return List containing the log-likelihood,
 #' smoothed state estimates \code{alphahat}, and the corresponding variances 
 #' \code{Vt} and \code{Ptt}.
 #' @export
 #' @rdname ekf_smoother
+#' @examples
+#' \donttest{ # Takes a while on CRAN
+#' set.seed(1)
+#' mu <- -0.2
+#' rho <- 0.7
+#' sigma_y <- 0.1
+#' sigma_x <- 1
+#' x <- numeric(50)
+#' x[1] <- rnorm(1, mu, sigma_x / sqrt(1 - rho^2))
+#' for(i in 2:length(x)) {
+#'   x[i] <- rnorm(1, mu * (1 - rho) + rho * x[i - 1], sigma_x)
+#' }
+#' y <- rnorm(length(x), exp(x), sigma_y)
+#' 
+#' pntrs <- cpp_example_model("nlg_ar_exp")
+#' 
+#' model_nlg <- ssm_nlg(y = y, a1 = pntrs$a1, P1 = pntrs$P1, 
+#'   Z = pntrs$Z_fn, H = pntrs$H_fn, T = pntrs$T_fn, R = pntrs$R_fn, 
+#'   Z_gn = pntrs$Z_gn, T_gn = pntrs$T_gn,
+#'   theta = c(mu= mu, rho = rho, 
+#'     log_sigma_x = log(sigma_x), log_sigma_y = log(sigma_y)), 
+#'   log_prior_pdf = pntrs$log_prior_pdf,
+#'   n_states = 1, n_etas = 1, state_names = "state")
+#'
+#' out_ekf <- ekf_smoother(model_nlg, iekf_iter = 0)
+#' out_iekf <- ekf_smoother(model_nlg, iekf_iter = 1)
+#' ts.plot(cbind(x, out_ekf$alphahat, out_iekf$alphahat), col = 1:3)
+#' }
 ekf_smoother <- function(model, iekf_iter = 0) {
   
+  iekf_iter <- check_integer(iekf_iter, "iekf_iter", positive = FALSE)
+  
   out <- ekf_smoother_nlg(t(model$y), model$Z, model$H, model$T, 
     model$R, model$Z_gn, model$T_gn, model$a1, model$P1, 
     model$theta, model$log_prior_pdf, model$known_params, 
@@ -92,6 +137,9 @@ ekf_smoother <- function(model, iekf_iter = 0) {
 #' @export
 ekf_fast_smoother <- function(model, iekf_iter = 0) {
   
+  
+  iekf_iter <- check_integer(iekf_iter, "iekf_iter", positive = FALSE)
+  
   out <- ekf_fast_smoother_nlg(t(model$y), model$Z, model$H, model$T, 
     model$R, model$Z_gn, model$T_gn, model$a1, model$P1, 
     model$theta, model$log_prior_pdf, model$known_params, 
